@@ -9,9 +9,8 @@ from functools import wraps
 from typing import Callable, Literal, Optional
 
 from .get_time_msg import get_time_msg
-# from peng.processing.post import penguin_wrapped_post_timer
-from penguin_py.processing.post import penguin_wrapped_post_timer
-from penguin_py.processing.pre import penguin_wrapped_pre_timer
+from .post import penguin_wrapped_post_timer
+from .pre import penguin_wrapped_pre_timer
 
 logging.basicConfig(level=logging.NOTSET)
 logger = logging.getLogger("penguin")
